@@ -5,7 +5,6 @@ from binance.types import OrderStatus, TimeInForce, Side, OrderType, validate_re
 
 class QueryOrderResponse(BaseModel):
   orderId: int
-  orderListId: int
   price: str
   origQty: str
   executedQty: str
@@ -21,7 +20,7 @@ class QueryOrderResponse(BaseModel):
   updateTime: int
   """Millis timestamp"""
   isWorking: bool
-  origQuoteOrderQty: str
+  isIsolated: bool
 
 
 @dataclass
@@ -41,5 +40,6 @@ class _QueryOrder(UserMixin):
       f'/sapi/v1/margin/order?{query}',
       headers={'X-MBX-APIKEY': self.api_key},
     )
+    # return r.json()
     return validate_response(r.text, QueryOrderResponse)
   
\ No newline at end of file
